@@ -1,9 +1,9 @@
-# @(#)Ident: ErrorLeader.pm 2013-06-06 13:03 pjf ;
+# @(#)Ident: ErrorLeader.pm 2013-06-09 20:31 pjf ;
 
 package Unexpected::TraitFor::ErrorLeader;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 5 $ =~ /\d+/gmx );
 
 use Moo::Role;
 use List::Util        qw(first);
@@ -16,11 +16,11 @@ my $Ignore = [];
 # Object attributes (public)
 has 'leader' => is => 'lazy', isa => SimpleStr, init_arg => undef;
 
-has 'level'  => is => 'ro',   isa => NonZeroPositiveInt, default => 1;
+has 'level'  => is => 'ro',   isa => NonZeroPositiveInt, default => sub { 1 };
 
 # Construction
 around 'as_string' => sub {
-   my ($next, $self, @args) = @_; my $str = $self->$next( @args );
+   my ($orig, $self, @args) = @_; my $str = $orig->( $self, @args );
 
    return $str ? $self->leader.$str : $str;
 };
@@ -87,7 +87,7 @@ Unexpected::TraitFor::ErrorLeader - Prepends a leader to the exception
 
 =head1 Version
 
-This documents version v0.3.$Rev: 1 $
+This documents version v0.3.$Rev: 5 $
 of L<Unexpected::TraitFor::ErrorLeader>
 
 =head1 Description
